@@ -641,7 +641,7 @@ class FirehosePutRecordAction(
                 stream: aws_cdk.aws_kinesisfirehose.IDeliveryStream,
                 *,
                 batch_mode: typing.Optional[builtins.bool] = None,
-                record_separator: typing.Optional["FirehoseRecordSeparator"] = None,
+                record_separator: typing.Optional[FirehoseRecordSeparator] = None,
                 role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
             ) -> None:
                 ...
@@ -721,7 +721,7 @@ class FirehosePutRecordActionProps(CommonActionProps):
                 *,
                 role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
                 batch_mode: typing.Optional[builtins.bool] = None,
-                record_separator: typing.Optional["FirehoseRecordSeparator"] = None,
+                record_separator: typing.Optional[FirehoseRecordSeparator] = None,
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
@@ -876,7 +876,7 @@ class IotRepublishMqttAction(
             def stub(
                 topic: builtins.str,
                 *,
-                quality_of_service: typing.Optional["MqttQualityOfService"] = None,
+                quality_of_service: typing.Optional[MqttQualityOfService] = None,
                 role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
             ) -> None:
                 ...
@@ -939,7 +939,7 @@ class IotRepublishMqttActionProps(CommonActionProps):
             def stub(
                 *,
                 role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
-                quality_of_service: typing.Optional["MqttQualityOfService"] = None,
+                quality_of_service: typing.Optional[MqttQualityOfService] = None,
             ) -> None:
                 ...
             type_hints = typing.get_type_hints(stub)
